import * as React from "react";
import { DirectionalHint, IContextualMenuItem } from "office-ui-fabric-react/lib/ContextualMenu";
import { IBaseProps, IPoint } from "office-ui-fabric-react/lib/Utilities";
import { IVssIconProps } from "../../VssIcon";
import { IVssContextualMenuItemProvider } from '../../VssContextualMenu';

export interface IContextualMenuButtonProps extends React.HTMLAttributes<HTMLButtonElement>, IBaseProps {
    /**
     * Whether or not the button should use display: none or visibility: hidden while it is not visible.
     */
    allocateSpaceWhileHidden?: boolean;

    /**
     * Specify true to get the primary/cta button styling
     */
    ctaButton?: boolean;

    /**
     * An optional directional hint to use for the contextual menu.
     */
    directionalHint?: DirectionalHint;

    /**
     * Function which returns set of items to display
     * @default []
     */
    getItems: () => IContextualMenuItem[];

    /**
     * Optional function to return an array of providers which can asynchronously add to the list of menu items
     * that are displayed.
     */
    getItemProviders?: () => IVssContextualMenuItemProvider[];

    /**
     * Properties of the icon that will be shown within the button
     */
    iconProps?: IVssIconProps;

    /**
     * Whether or not the consumer of this component wants to force the menu
     * to be shown.
     */
    isOpen?: boolean;

    /**
     * Click handler for the button, called before the menu is shown.
     * If undefined or false are returned, ev.stopPropagation() will be called.
     * Return true to allow the click event to propagate to parent elements.
     */
    onClick?: (e: React.MouseEvent<HTMLElement>) => void | boolean;

    /**
     * Dismiss handler for the menu. Allows consumer of this component to perform
     * additional actions when the menu is being dismissed.
     */
    onDismiss?: () => void;

    /**
     * If true, show the content of the "title" property as a tooltip for this button
     */
    showTooltip?: boolean;

    /**
     * The specific point at which the contextual menu should be shown
     * @deprecated Use 'target' instead.
     */
    targetPoint?: IPoint;

    /**
     * Text applied to the aria-label of the button (and the tooltip if showTooltip is true)
     */
    title?: string;

    /**
     * Whether or not the menu should appear at the point of the click target - default value is false
     * @deprecated Use 'target' instead.
     */
    useTargetPoint?: boolean;

    /**
      * The target that the ContextualMenu should try to position itself based on.
      * It can be either an HTMLElement a querySelector string of a valid HTMLElement
      * or a MouseEvent. If MouseEvent is given then the origin point of the event will be used.
      */
    target?: HTMLElement | string | MouseEvent | IPoint | null;
}