/// <reference types="react" />
import { BaseComponent } from 'office-ui-fabric-react/lib/Utilities';
import { IObservableComponentProps } from '../../Components/Dynamic/ObservableComponent.Props';
export interface IObservableComponentState {
    [propName: string]: any;
}
/**
 * Handles subscription to properties that are IObservableValues, so that components don't have to handle on their own.
 *
 * Usage:
 *
 * <ObservableComponent myObservableValue={observableValue} className='foo'>
 *   <MyComponent myObservableValue='' />
 * </ObservableComponent>
 *
 * Your component will get re-rendered with the new value of myObservableValue whenever that value changes.
 * Additionally, any additional props set on ObservableComponent will also get passed down.
 */
export declare class ObservableComponent extends BaseComponent<IObservableComponentProps, IObservableComponentState> {
    private _observableSubscriptionDelegates;
    constructor(props: IObservableComponentProps);
    componentWillMount(): void;
    componentWillUnmount(): void;
    componentWillReceiveProps(nextProps: IObservableComponentProps): void;
    render(): JSX.Element;
    private _subscribe(propName, props);
    private _unsubscribe(propName, props);
    private _onValueChanged(propName, value, action);
}
