import * as React from "react";
import { IBaseProps } from "office-ui-fabric-react/lib/Utilities";
import { IFilter } from '../../Utilities/Filter';

/**
 * Base set of properties for any filter bar item component
 */
export interface IFilterBarItemProps extends IBaseProps {
    componentRef?: (component: IFilterBarItem) => void;

    /**
     * The filter store that this filter bar updates (optional, the parent FilterBar's filter is used by default)
     */
    filter?: IFilter;

    /**
     * The unique key for this filter item whose value is updated by changes to this filter item. 
     */
    filterItemKey: string;

    /**
     * Text to show for the filter in the case that there is no current value
     */
    placeholder?: string;

    /**
     * Comparer of filter values to determine when the filter needs to be updated.
     */
    filterValueComparer?: (a: any, b: any) => boolean;
}

export interface IFilterBarItem {
    /**
     * Focuses the item
     */
    focus(): void;

    /**
     * Re-render the FilterBarItem
     */
    forceUpdate(): void;
}