import * as React from "react";
import { IBaseProps } from "office-ui-fabric-react/lib/Utilities";
import { IHubBreadcrumbItem, IHubPickerDropdownProps } from "../../Components/HubHeader/HubBreadcrumb.Props";
import { IItemPickerProvider } from "../../Components/PickList/PickList.Props";
import { IObservableValue } from '../../Utilities/Observable';
import { IVssIconProps } from "../../VssIcon";

export interface IHubHeaderProps extends IBaseProps {
    /**
     * Title of the page, shown in the header, to the right of any breadcrumb items. Does not need to be provided if a
     * headerItemPicker is set.
     */
    title?: string;

    /**
     * Icon shown on the left side of the header (when not using breadcrumbs)
     */
    iconProps?: IVssIconProps;

    /**
     * Optional list of breadcrumbs to display in the header to the left of the title
     */
    breadcrumbItems?: IHubBreadcrumbItem[];

    /**
     * Specifies behavior for the PickList that can be shown next to the header title.
     */
    headerItemPicker?: IItemPickerProvider | IObservableValue<IItemPickerProvider>;
    
    /**
     * Optional max width to set on breadcrumb items
     */
    maxBreadcrumbItemWidth?: string;

    /**
     * Aria label to be passed along to HubBreadcrumb
     */
    hubBreadcrumbAriaLabel?: string;

    /**
     * If true, do not show the item picker and make breadcrumb non-clickable.
     */
    nonInteractive?: boolean;

    /**
     * If true, do not show the full breadcrumb, only the main/title item (last breadcrumb item).
     */
    collapseBreadcrumb?: boolean;
    
    /**
     * Class name to use for the pick list for the header item picker dropdown
     */
    pickListClassName?: string;
    
    /**
     * 
     */
    pickListMinWidth?: number;
}