import { IObservable, Observable } from '../../Utilities/Observable';
import { IVssIconProps } from "../../VssIcon";
export declare const ITEM_CHANGE_EVENT = "item-changed";
export interface IItemState {
    /**
     * The value to display for this item's indicator. Typically presented as a tooltip on the indicator.
     */
    title: string;
    iconProps?: IVssIconProps;
}
export interface IItem extends IObservable<IItemState> {
    /**
     * Gets the current state of the item.
     */
    getState: () => IItemState;
    /**
     * Sets a new state for the item.
     * @param state New item state.
     * @param supressChangeEvent If true, don't invoke changed callback at this time.
     */
    setState(state: IItemState, suppressChangeEvent?: boolean): void;
}
export interface IItemProps {
    /**
     * Initial state of the item.
     */
    initialState: IItemState;
}
export declare class Item extends Observable<IItemState> implements IItem {
    private _currentState;
    constructor(props: IItemProps);
    /**
     * Gets the current state of the item.
     */
    getState(): IItemState;
    /**
     * Sets a new state for the item.
     * @param state New item state.
     * @param supressChangeEvent If true, don't invoke changed callback at this time.
     */
    setState(state: IItemState, supressChangeEvent?: boolean): void;
}
