import * as React from "react";
import { IBaseProps } from "office-ui-fabric-react/lib/Utilities";
import { IItem } from "../../Components/ItemIndicator/Item";
import { IVssIconProps } from "../../VssIcon";
import { BaseButton } from "office-ui-fabric-react/lib/Button";

export interface IItemIndicatorProps extends IBaseProps {
    /**
     * The value to display for this item's indicator. Typically presented as a tooltip on the indicator.
     */
    title: string;

    /*
     * Icon that represents the state of the indicator for the list item.
     */
    iconProps?: IVssIconProps;
    
    /**
     * An onClick handler indicates that the indicator is actionable. 
     */
    onClick?: (ev?: React.MouseEvent<HTMLButtonElement | HTMLAnchorElement | BaseButton>, item?: IItem) => any;

    /**
     * Optional item to keep the state of the indicator.
     */
    item?: IItem;

    /**
     * Class name to place on the indicator root element
     */
    className?: string;
}

export interface IItemIndicatorSetProps extends IBaseProps {

    /**
     * Indicators to display in the set
     */
    indicators: IItemIndicatorProps[];

    /**
     * Handler for clicks in the indicator set that do not fall on an indicator that has an onClick handler.
     */
    onClick?: (ev: React.MouseEvent<HTMLElement>) => void;
}