/// <reference types="react" />
import { BaseComponent } from 'office-ui-fabric-react/lib/Utilities';
import { IPickList, IPickListItem, IPickListProps } from '../../Components/PickList/PickList.Props';
import "./PickList.css";
export interface IPickListState {
    /**
     * The currently selected keys in the PickList
     */
    selectedKeys?: string[];
    initiallySelectedKeys?: string[];
    /**
     * The current set of items. If a promise is supplied through the items prop, then this
     * is initially empty until the promise has been resolved.
     */
    items?: any[];
    /**
     * True if a promise was supplied for the items prop and it has not yet been fulfilled.
     */
    itemsLoading?: boolean;
    /**
     * The wrapped data models for all items provided to the PickList
     */
    groupDictionary?: {
        [key: string]: IPickListItemInternal[];
    };
    searchResults?: any[];
    /**
     * The wrapped data models for all items provided to the PickList, given the current search text
     */
    filteredItems?: IPickListItemInternal[];
    isSearchInProgress?: boolean;
    selectedOperatorKey?: string;
    initiallySelectedOperatorKey?: string;
}
export interface IPickListItemInternal extends IPickListItem {
    isSelected: boolean;
    data?: any;
    isSeparator?: boolean;
    isGroupHeader?: boolean;
    isMessage?: boolean;
    isLoadingIndicator?: boolean;
    onRender?: () => JSX.Element;
}
export declare class PickList extends BaseComponent<IPickListProps, IPickListState> implements IPickList {
    private _id;
    private _focusZone;
    private _searchFocusZone;
    private _textField;
    private _pickListElement;
    private _operatorGroup;
    private _firstRow;
    private _isMounted;
    private _maintainsOwnState;
    private _initialItemsLoaded;
    private _hideLoadingContent;
    private _loadingContentHidden;
    private _focusOnInitialLoad;
    private _hideSearchingContent;
    private _searchingContentHidden;
    private _hideSearchingContentTimeout;
    private _searchTextChangeDelegate;
    private _searchText;
    private _itemsAnnouncer;
    private _itemDictionary;
    constructor(props: IPickListProps);
    clearSelection(): void;
    reset(): void;
    selectAll(): void;
    focus(): boolean;
    forceUpdate(): void;
    componentWillMount(): void;
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentWillReceiveProps(newProps: IPickListProps): void;
    render(): JSX.Element;
    private _rebuild(props);
    private _buildFromItems(props, items, loading);
    private _onSearchContainerFocused;
    private _onKeyDown;
    private _onSearchTextChanged;
    private _onClearInputKeyPress;
    private _onClearInputClick;
    private _updateSearchText;
    private _announceSearchResults(filteredGroupDictionary, isSearchInProgress, itemsLoading);
    private _wrapItems(items, selectedKeys, overrideGroupKey?);
    private _groupItems(items, initialGroupDictionary?);
    private _filterByText(searchText, groupDictionary);
    private _buildGroupedItems(searchText, isSearchInProgress, groupDictionary, groups, selectedKeys, itemsLoading);
    private _getOnSearchPromise(searchText);
    private _onSelectionChanged;
    private _onOperatorChanged;
    private _onRenderCell;
    private _onRenderCellSingleSelection;
    private _onRenderCellMultipleSelection;
    private _onSingleSelectionChanged(key, disabled);
    private _onMultipleSelectionChanged(key, isSelected, disabled);
    private _onActiveElementChanged;
    private _getIndicators(pickListItem, indicators?);
    private _getKeysFromItems(items, allItems);
    private _hasNewItems(newProps);
    private _isThenable(obj);
    private _arrayEquals(array1, array2);
}
