import * as React from "react";
import { IColumn } from "OfficeFabric/DetailsList"

export interface ITreeList<T> {
}

export interface ITree<T> {
}

export interface ITreeListItem<T> {
    /** A reference back to the ITreeItem for this list item. */
    treeItem: ITreeItem<T>;

    /** How many levels deep we should indent this row. */
    indentLevel: number;

    /** Whether or not the item is able to expanded/collapsed. */
    isExpandable: boolean;

    /** Whether or not the item is currently expanded - defaults to false. */
    isExpanded?: boolean;
}

export interface ITreeItem<T> {
    /** A unique identifier across all items in the tree. */
    id: string;

    /** An optional reference back to the original item wrapped by the tree item. */
    item?: T;

    /** In the tree's hierarchy, the items which are children of this item. 
     * Passing an empty array indicates that we want to be expandable, but we do not have any children - provides a 
     * way to a folder existing, but getting its items asynchronously. A value of undefined means that this item is not expandable. */
    children: ITreeItem[] | undefined;

    /**
     * The initial expansion state for this item when the tree is first rendered. Changing this value on subsequent renders will have no effects.
     */
    defaultIsExpanded?: boolean;
}

interface ISharedTreeProps {

    /**
     * Columns to pass along to the VssDetailsList. Currently must have an onRender which will be wrapped.
     */
    columns: IColumn[];

    /**
     * Which column should contain the collapse/expand behavior for the tree. If not provided, defaults to the first column.
     */
    primaryTreeColumnKey?: string;

    ////////////////////////////////
    // IVssDetailsListProps below //
    ////////////////////////////////

    /**
    * Which column should contain the actions button trigger
    */
    actionsColumnKey?: string;

    /**
     * Whether or not the actions button should use display: none or visibility: hidden while it is not visible.
     */
    allocateSpaceForActionsButtonWhileHidden?: boolean;

    /**
     * A callback used to dynamically create the list of menu items
     */
    getMenuItems?: (activatedItem: any) => IContextualMenuItem[];

    /**
     * A callback used to dynamically create the list of menu item providers.  These can be used to asynchronously load menu items.
     */
    getMenuItemProviders?: (activatedItem: any) => IVssContextualMenuItemProvider[];
}

export interface ITreeListProps<T> extends ISharedTreeProps {
    /**
     * The list of all items to be rendered in the tree list. 
     */
    treeListItems: ITreeListItem<T>[];

    /**
     * Called whenever an item is expanded or collapsed. The isExpanded value on the treeListItem is the current 
     * (pre-expansion/collapse) state of the item.
     */
    onItemToggled: (treeListItem: ITreeListItem<T>) => void;

    /**
     * Optional callback to access the ITree interface. Use this instead of ref for accessing
     * the public methods and properties of the component.
     */
    componentRef?: (component: ITreeList<T>) => void;
}

export interface ITreeProps<T> extends ISharedTreeProps {
    /**
     * The set of root - level tree items which should be rendered by the tree.
     * This component will turn these items into a flat list to be rendered by a TreeList
     * and maintain the expansion state of all of the items.
     */
    treeItems: ITreeItem<T>[];

    /**
    * Optional callback to access the ITree interface. Use this instead of ref for accessing
    * the public methods and properties of the component.
    */
    componentRef?: (component: ITree<T>) => void;
}