import { IContextualMenuProps, IContextualMenuItem } from "office-ui-fabric-react/lib/ContextualMenu";


export interface IVssContextualMenuItemProvider {

    /**
     * Loads menu items to be included with current menu.
     * @param itemsUpdated Function to be invoked when menuitems have been updated
     * @param itemsInitialized Function to be invoked when menuitems have been initialized     
     */
    loadItems(itemsUpdated: (itemsUpdated: IVssContextualMenuItem[], itemsRemoved?: string[], groupInfo?: IVssContextualMenuGroup[]) => void, itemsInitialized: () => void): void;
}

export interface IVssContextualMenuProps extends IContextualMenuProps {
    /**
     * List of menu item providers
     */
    providers?: IVssContextualMenuItemProvider[];

    /**
     * If a mouseLeaveDelayMs is specified the menu will close if the
     * mouse leaves the menu elements from the popup for longer than
     * the value in milliseconds.
     */
    mouseLeaveDelayMs?: number;

    /**
     * Collection of menu items.
     * @default []
     */
    items: IVssContextualMenuItem[];

    /**
     * Predefined groups for the menu items. Groups do not have to be predefined, but they must be
     * in order to specify additional properties.
     */
    groups?: IVssContextualMenuGroup[];
}

/**
 * Provides VSS-specific extensions to IContextualMenuItems displayed in IVssContextualMenus.
 */
export interface IVssContextualMenuItem extends IContextualMenuItem {
    /**
     * True if menu item should be hidden.
     */
    hidden?: boolean;
    /**
     * Sets the order items should be displayed in (lowest first, undefined and 0 last).
     */
    rank?: number;
    /**
     * Items with the same group name are sorted together and separated from other items with separators.
     */
    groupKey?: string;
    /**
     * Method which can be invoked to invalidate a menu item.
     */
    invalidateItem?: () => void;
}

/**
 * Defines groups for grouping IVssContextualMenuItems.
 */
export interface IVssContextualMenuGroup {
    /**
     * Key used to identify the group, maps to IVssContextualMenuItem.groupKey.
     */
    key: string;
    /**
     * Text displayed to label the group (if showGroupName is true).
     */
    name?: string;
    /**
     * Sets the order groups should be displayed in (lowest first, undefined and 0 last)
     */
    rank?: number;
    /**
     * If true, display the group name at the top of the group.
     */
    showGroupName?: boolean;
}