/// <reference types="react" />
import { BaseComponent } from 'office-ui-fabric-react/lib/Utilities';
import { IVssContextualMenuItem, IVssContextualMenuProps } from '../../Components/VssContextualMenu/VssContextualMenu.Props';
import "./VssContextualMenu.css";
/**
 * State this component manages
 */
export interface IVssContextualMenuState {
    /** The items we're displaying (sorted and with separators and group headings and the like). */
    displayItems: IVssContextualMenuItem[];
    loadingTimeout?: number;
}
/**
 * Creates office fabric contextual menu, also takes contribution ids to get menu contributions from extensions
 * P.S: ContextualMenu generates some warnings look: https://github.com/OfficeDev/office-ui-fabric-react/issues/357
 */
export declare class VssContextualMenu extends BaseComponent<IVssContextualMenuProps, IVssContextualMenuState> {
    private static _activeMenu?;
    private _submenuComponent?;
    private _activeElement?;
    private _targetElement?;
    private _isMounted;
    private timers?;
    private closeTimeout?;
    /** The items we have */
    private _items;
    /** The groups to display */
    private _groups;
    /** Forces the display of group names for development purposes. */
    private _forceGroupNames;
    protected subMenuId: string;
    constructor(props: IVssContextualMenuProps);
    render(): JSX.Element;
    componentWillMount(): void;
    componentWillUnmount(): void;
    componentDidMount(): void;
    componentWillReceiveProps(nextProps: IVssContextualMenuProps): void;
    contains(element: HTMLElement | null): boolean;
    dismiss(reason?: Event, dismissAll?: boolean): void;
    /**
     * Sort and group our menu items
     * @param items
     */
    private _arrangeItems(items, groupInfo?);
    private _clearTimeout(timeoutId);
    private _invalidateItem;
    private _findMenuItems(menuId);
    private _findItemIndex(matches, key);
    private _focusItem(matches, itemIndex);
    private _itemsChanged;
    /**
     * Arrange the items into groups and put separators between them and headings above them as needed.
     * @param items
     */
    private _groupItems(items, groupInfo?);
    private _onDismiss;
    private _onRenderSubMenu;
    private _removeConsecutiveSeparators(items);
    private _setTimeout(callback, milliseconds?, ...args);
    /**
     * Sort the items according to their rank property.
     * @param items
     */
    private _sortItems(items);
}
