import * as React from "react";
import { IBaseProps } from "office-ui-fabric-react/lib/Utilities";
import { IIconStyles } from 'office-ui-fabric-react/lib/Icon';
import { IImageProps } from "office-ui-fabric-react/lib/Image";

// Try to make these line up with Fabric's IconType so that we can assign IconType to VssIconType
// and have it Just Work(tm).
export const enum VssIconType {
    /**
     * Use an icon from the Fabric icon set
     */
    fabric = 0,

    /**
     * Use an icon from the Bowtie icon set
     * @deprecated Use only fabric icons. 
     */
    bowtie = 1,

    /**
     * Use an image as an icon
     */
    image = 3,
}

export interface IVssIconProps extends React.HTMLAttributes<HTMLElement>, IBaseProps {
    /**
     * Name of the icon to be used. Note: for Bowtie icons there is
     * no need for the "bowtie-" prefix.
     */
    iconName?: string;

    /**
     * Type of icon to use. This determines the icon font.
     */
    iconType?: VssIconType;

    /**
     * If using an image as the icon, specify its props.
     */
    imageProps?: IImageProps;

    /**
     * Use for applying programatic styles to an icon, such as user defined colors
     * Please use className for page related styling
     */
    styles?: IIconStyles;
}