import { IBaseProps } from "office-ui-fabric-react/lib/Utilities";

/**
 * Class to provide identity information to the VssPersona component.
 *
 * This interface is still in flux and should not be implemented outside of VssPreview.
 */
export interface IIdentityDetailsProvider {
    /**
     * Return a URL to a profile image suitable for display at size pixels.
     */
    getIdentityImageUrl(size: number): string;
    /**
     * Gets the user's displayname.
     */
    getDisplayName(): string;
    /**
     * (optional) Render an element to display on delayed hover of the VssPersona
     * e.g. a profile card or tooltip containing the full display name
     */
    onRenderPersonaCard?(image: HTMLElement, onDismiss: () => void): JSX.Element;
}

/**
 * Preset sizes for VssPersonas
 */
export type VssPersonaSize =
    "extra-extra-small" // 16px
    | "extra-small" // 18px
    | "small" // 24px
    | "small-plus" // 28px
    | "medium" // 32px
    | "medium-plus" // 40px;
    | "large" // 48px
    | "extra-large"; // 72px

/**
 * Props for VssPersona
 */
export interface IVssPersonaProps extends IBaseProps {
    cssClass?: string;
    /** Size of image to display. Use VssPersonaSize presets or specify a size in pixels. */
    size?: VssPersonaSize;
    /** Provides information about an identity */
    identityDetailsProvider: IIdentityDetailsProvider;
    /** If true, do not show persona card on hover */
    suppressPersonaCard?: boolean;
    /** Set when VssPersona is within a focus zone **/
    dataIsFocusable?: boolean;
    /** Set when VssPersona is a tab stop but not in focus zone **/
    isTabStop?: boolean;
    /** Alternate text for VSSPersona image to display when image load does not succeed **/
    imgAltText?: string;
    /** Optional callback on image load error **/
    onImageError?: (event: React.SyntheticEvent<HTMLImageElement>) => void;
}