import * as React from "react";
import { IBaseProps } from "office-ui-fabric-react/lib/Utilities";
import { BaseButton } from "office-ui-fabric-react/lib/Button";

/**
 * Defines options for displaying actions in ZeroData component.
 */
export const enum ZeroDataActionType {
    ctaButton = 0,
    button = 1,
}

/**
 * Describes an item displayed by the ZeroData component.
 */
export interface IZeroDataItem {
    /**
     * Path to the image to display.
     */
    imagePath: string;
    /**
     * Alt text to set for the image
     */
    imageAltText: string;
    /**
     * Primary text to display
     */
    primaryText?: string;
    /**
     * Secondary text to display
     */
    secondaryText?: string | JSX.Element;
    /**
     * Text to put on the button. If not set, no button will be rendered.
     */
    actionText?: string;
    /**
     * The type of button to render. Default is CTA button.
     */
    actionType?: ZeroDataActionType;
    /**
     * Callback called when the user clicks on the button
     */
    onActionClick?: (ev?: React.MouseEvent<HTMLButtonElement | BaseButton>, item?: IZeroDataItem) => void;
}

/**
 * Properties for the ZeroData component.
 */
export interface IZeroDataProps extends IZeroDataItem, IBaseProps {

}

/**
 * Properties for the ZeroDataMultiple component.
 */
export interface IZeroDataMultipleProps extends IBaseProps {
    /** ZeroData items to display */
    items: IZeroDataItem[];
}