import * as React from "react";

export interface IUserAction {
    /**
     * Unique id to identify the user action.
     */
    key: string;

    /**
     * Text to be displayed for the element associated with this user action.
     */
    name?: string;

    /**
     * Optional title for displaying text when hovering over the element associated with this user action.
     */
    title?: string;

    /**
      * Optional accessibility label (aria-label) attribute that will be stamped on to the element.
      */
    ariaLabel?: string;

    /**
     * Callback issued when the user action executes.
     */
    onClick?: (ev?: React.MouseEvent<HTMLElement> | React.KeyboardEvent<HTMLElement>, action?: IUserAction) => void;

    /**
     * An optional URL to navigate when the user action occurs.
     */
    href?: string;

    /**
     * An optional target specifying how the user action occurs in conjunction with the href
     */
    target?: string;
}