import { ObservableArray } from "../Observable";
import { IItemProvider } from "./interfaces";
/**
 * Given an IItemProvider, implements an ObservableArray that contains the items provided by the provider.
 */
export declare class ContributedItemArray<TContributedItem, TItem> extends ObservableArray<TItem> {
    constructor(itemProvider: IItemProvider<TContributedItem>, mapDelegate: (item: TContributedItem) => TItem);
}
/**
 * Implements an IItemProvider that provides modified versions of items it gets from the source provider.
 */
export declare class MutatedItemProvider<TInItem, TOutItem = TInItem> implements IItemProvider<TOutItem> {
    private provider;
    private mutator;
    /**
     * @param provider provider that provides the source items
     * @param mutator function that modifies the items before providing them to this object's listener
     */
    constructor(provider: IItemProvider<TInItem>, mutator: (item: TInItem) => TOutItem);
    loadItems(itemsUpdated: (items: TOutItem[]) => void): void;
}
