import { Observable } from '../Observable';
import { IViewOptions, IViewOptionsProps, IViewOptionsValues } from "./interfaces";
export declare const VIEW_OPTIONS_CHANGE_EVENT = "view-option-changed";
export declare class ViewOptions implements IViewOptions {
    private observable;
    private currentState;
    constructor(props?: IViewOptionsProps, observable?: Observable<IViewOptionsValues>);
    subscribe(observer: (value: IViewOptionsValues, action: string) => void, action?: string): void;
    unsubscribe(observer: (value: IViewOptionsValues, action: string) => void, action?: string): void;
    /**
     * Gets a dictionary containing the current values of all view options.
     */
    getViewOptions(): IViewOptionsValues;
    /**
     * Sets the current values of all view options.
     * @param state Dictionary of all current view option values.
     * @param supressChangeEvent If true, don't invoke the onViewOptionsChanged callback at this time
     */
    setViewOptions(state: IViewOptionsValues, supressChangeEvent?: boolean): void;
    /**
     * Clears all view option values
     */
    clear(): void;
    /**
     * Gets the value of the view option.
     * @param key View option item key.
     */
    getViewOption(key: string): any;
    /**
     * Sets the current value of the specified option.
     * @param key Key of the view option.
     * @param supressChangeEvent If true, don't invoke the onViewOptionsChanged callback at this time
     */
    setViewOption(key: string, value: any): void;
    private _triggerStateChange(changedState);
}
