import { IObservable } from "../Observable/interfaces";

/**
 * Dictionary of view option values.
 */
export interface IViewOptionsValues {
    [key: string]: any;
}

/**
 * Store for the view options.
 * 
 * Events:
 * 
 *   VIEW_OPTIONS_CHANGE_EVENT: IViewOptionsValues
 *   Fired when a view option has changed. The event contains the changed state values.
 */
export interface IViewOptions extends IObservable<IViewOptionsValues> {
    /**
     * Gets a dictionary containing the current values of all view options.
     */
    getViewOptions(): IViewOptionsValues;

    /**
     * Sets the current values of all view options.
     * @param state Dictionary of all current view option values.
     * @param supressChangeEvent If true, don't invoke the onViewOptionsChanged callback at this time
     */
    setViewOptions: (state: IViewOptionsValues, supressChangeEvent?: boolean) => void;

    /**
     * Gets the value of the view option.
     * @param key View option item key.
     */
    getViewOption: (key: string) => any;

    /** 
     * Sets the current value of the specified option.
     * @param key Key of the view option.
     * @param supressChangeEvent If true, don't invoke the onViewOptionsChanged callback at this time
     */
    setViewOption: (key: string, value: any) => void;

    /**
     * Clears all view option values
     */
    clear: () => void;
}

export interface IViewOptionsProps {

    /**
     * Initial state of the view options.
     */
    initialState?: IViewOptionsValues;
}